#!/bin/bash

#author				: hennes (jm@rapidrabbit.de) -> original build-script by Peter van Eerten (Pjot)
#last changed		: 02-august-2007

#package			: toppler
#homepage			: http://toppler.sourceforge.net/
#source location	: http://prdownloads.sourceforge.net/toppler/toppler-1.1.3.tar.gz?download
#dependencies		: coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,openssl,perl,sdl,sysfsutils,utempter,xorg,xterm,zlib

# ----- credentials
softname="toppler"
softversion="1.1.3"
srcurl="http://prdownloads.sourceforge.net/toppler/toppler-1.1.3.tar.gz?download"
arch=i486
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/man/man6
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
toppler: toppler (platform game)
toppler:
toppler: In this game you have to help a cute little green animal switch
toppler: off some kind of "evil" mechanism. The "power off switch" is
toppler: hidden somewhere in high towers. On your way to the target you
toppler: need to avoid a lot of strange robots that guard the tower.
toppler:
toppler:
toppler:
toppler:
toppler:
EOF

# ----- extract source-archive
srcdir=$softname-$softversion
rm -rf $srcdir
if [ -f $softname-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -zxvf $softname-$softversion.tar.gz
cd $srcdir

# ----- create package-dependent directories
mkdir -p $dest/usr/doc/$srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- configure
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
	--prefix=$prefix \
	--localstatedir=$prefix/share \
	--disable-debug
	
# ----- make
make $numjobs
	
# ----- make install
make install DESTDIR=$dest

# ----- add default-files
mv $dest/usr/share/doc/$softname/* $dest/usr/doc/$srcdir
rm -rf $dest/usr/share/doc
cp -a \
	ABOUT-NLS INSTALL VERSION \
	$dest/usr/doc/$srcdir

# ----- treat icon-file
cp $builddir/icon-toppler-48.png $dest/usr/share/icons/hicolor/48x48/apps/toppler.png
cp $builddir/icon-toppler-48.png $destsrc
rm -rf $dest/usr/share/pixmaps

# ----- make .desktop-file
rm -f $dest/usr/share/applications/*
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Tower Toppler
Comment=A clone of the 'Nebulus' game on old 8 and 16 bit machines.
Comment[de]=Clone des alten Spiels 'Nebulus'
Comment[cs]=Clone hry 'Nebulus' z dob 8 a 16 bitovÃœch poÄÃ­taÄÅ¯.
Exec=toppler
Icon=toppler
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Encoding=UTF-8
EOF

# ----- set permissions
chmod a+rw $dest/usr/share/$softname/toppler.hsc

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- get-source-script
cat << EOF > "$destsrc/getsrc.sh"
wget -c $srcurl
EOF

chmod a+x "$destsrc/getsrc.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
mv $dest/usr/share/man/man6/*.* $dest/usr/man/man6
rm -rf $dest/usr/share/man

for mandir in $(find . -name man -type d) ; do
	if [ -d $mandir ]; then
		( cd $mandir
		  find . -type f -name "*.?" -exec gzip -9 {} \;
		)
	fi
done

# ----- packaging
chown -R root.root $dest
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $builddir/$package.dep
coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,openssl,perl,sdl,sysfsutils,utempter,xorg,xterm,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
